@@ -48,7 +48,7 @@ class SharePointManager:
         self._drive_cache = {}
         self._load_cache()
         self._initialize_app()
-        self._authenticate()
+        # self._authenticate()
         self._get_site_id()
 
     def _prepare_sharepoint_site_url(self):
@@ -137,36 +137,51 @@ class SharePointManager:
         accounts = self.app.get_accounts()
         if accounts:
             logging.info(f"Found existing account: {accounts[0]['username']}")
-            self.result = self.app.acquire_token_silent(self.scopes, account=accounts[0])
+            self.result = self.app.acquire_token_silent(self.scopes, account=accounts[0], force_refresh=True)
+            if self.cache.has_state_changed:
+                self._update_public_service_data(self.token_name, self.cache.serialize())
         else:
             self.result = None
 
-    def _authenticate(self):
-        """ Authenticate and acquire token
-
-        """
-        if not self.result:
-            logging.info("No valid token in cache, need to log in via browser.")
-            flow = self.app.initiate_auth_code_flow(scopes=self.scopes, redirect_uri="http://localhost:8090")
-            print("Please open the following URL in your browser and log in:")
-            print(flow["auth_uri"])
-            auth_response_url = input("Enter the full redirect URL from your browser: ")
-            from urllib.parse import urlparse, parse_qsl
-            parsed = urlparse(auth_response_url)
-            auth_response = dict(parse_qsl(parsed.query))
-            self.result = self.app.acquire_token_by_auth_code_flow(flow, auth_response)
-
-        if self.cache.has_state_changed:
-            self._update_public_service_data(self.token_name, self.cache.serialize())
+    # def _authenticate(self):
+    #     """ Authenticate and acquire token
+    #
+    #     """
+    #     if not self.result:
+    #         logging.info("No valid token in cache, need to log in via browser.")
+    #         flow = self.app.initiate_auth_code_flow(scopes=self.scopes, redirect_uri="http://localhost:8090")
+    #         print("Please open the following URL in your browser and log in:")
+    #         print(flow["auth_uri"])
+    #         auth_response_url = input("Enter the full redirect URL from your browser: ")
+    #         from urllib.parse import urlparse, parse_qsl
+    #         parsed = urlparse(auth_response_url)
+    #         auth_response = dict(parse_qsl(parsed.query))
+    #         self.result = self.app.acquire_token_by_auth_code_flow(flow, auth_response)
+    #
+    #     if self.cache.has_state_changed:
+    #         self._update_public_service_data(self.token_name, self.cache.serialize())
 
     def _get_access_token(self):
         """ Get access token
 
         """
-        if "access_token" in self.result:
-            return self.result["access_token"]
-        else:
-            raise Exception("Failed to obtain access token.")
+        # if "access_token" in self.result:
+        #     return self.result["access_token"]
+        # else:
+        #     raise Exception("Failed to obtain access token.")
+        accounts = self.app.get_accounts()
+        if accounts:
+            refreshed = self.app.acquire_token_silent(
+                self.scopes,
+                account=accounts[0],
+                force_refresh=True
+            )
+            if refreshed:
+                self.result = refreshed
+                if self.cache.has_state_changed:
+                    self._update_public_service_data(self.token_name, self.cache.serialize())
+
+        return self.result["access_token"]
 
     def _get_headers(self):
         """ Prepare headers for requests"""
